@@ -1,14 +1,16 @@
 package LINE::Bot::API;
 use strict;
 use warnings;
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 
 use LINE::Bot::API::Builder::SendMessage;
 use LINE::Bot::API::Client;
 use LINE::Bot::API::Event;
 use LINE::Bot::API::Response::Common;
 use LINE::Bot::API::Response::Content;
+use LINE::Bot::API::Response::FriendDemographics;
 use LINE::Bot::API::Response::NumberOfSentMessages;
+use LINE::Bot::API::Response::NumberOfMessageDeliveries;
 use LINE::Bot::API::Response::Profile;
 use LINE::Bot::API::Response::GroupMemberProfile;
 use LINE::Bot::API::Response::RoomMemberProfile;
@@ -18,6 +20,7 @@ use LINE::Bot::API::Response::RichMenuList;
 use LINE::Bot::API::Response::TargetLimit;
 use LINE::Bot::API::Response::TotalUsage;
 use LINE::Bot::API::Response::Token;
+use LINE::Bot::API::Response::NumberOfFollowers;
 
 use constant {
     DEFAULT_MESSAGING_API_ENDPOINT => 'https://api.line.me/v2/bot/',
@@ -151,6 +154,12 @@ sub leave_group {
     LINE::Bot::API::Response::Common->new(%{ $res });
 }
 
+sub get_friend_demographics {
+    my($self) = @_;
+    my $res = $self->request(get => "insight/demographic");
+    LINE::Bot::API::Response::FriendDemographics->new(%{ $res });
+}
+
 sub get_target_limit_for_additional_messages {
     my($self, $date) = @_;
     my $res = $self->request(get => "message/quota");
@@ -187,6 +196,14 @@ sub get_number_of_send_broadcast_messages {
     LINE::Bot::API::Response::NumberOfSentMessages->new(%{ $res });
 }
 
+sub get_number_of_message_deliveries {
+    my($self, $opts) = @_;
+    my $date = $opts->{date} or croak "get_number_of_message_deliveries: Missing a `date` parameter.";
+
+    my $res = $self->request(get => "insight/message/delivery?date=${date}", +{});
+    LINE::Bot::API::Response::NumberOfMessageDeliveries->new(%{ $res });
+}
+
 sub validate_signature {
     my($self, $json, $signature) = @_;
     LINE::Bot::API::Event->validate_signature($json, $self->{channel_secret}, $signature);
@@ -349,6 +366,13 @@ sub revoke_channel_access_token {
     }
 }
 
+sub get_number_of_followers {
+    my ($self, $opts) = @_;
+    my $date = $opts->{date} or croak "get_number_of_followers: Missing a `date` parameter.";
+
+    my $res = $self->request(get => "insight/followers?date=${date}");
+    LINE::Bot::API::Response::NumberOfFollowers->new(%{ $res });
+}
 
 1;
 __END__
@@ -559,6 +583,29 @@ Gets the number of messages sent in the current month.
 
 See also the LINE Developers API reference of this method:  L<https://developers.line.biz/en/reference/messaging-api/#get-consumption>
 
+=head2 C<< get_number_of_message_deliveries({ date => ... }) >>
+
+Get the number of messages sent from LINE official account on a specified day.
+
+See also the LINE Developers API reference of this method: L<https://developers.line.biz/en/reference/messaging-api/#get-number-of-delivery-messages>
+
+The argument is a HashRef with one pair of mandatary key-values;
+
+    { date => "20191231" }
+
+The formate of date is "yyyyMMdd", that is, year in 4 digits, month in
+2 digits, and date-of-month in 2 digits.
+
+The return value C<$res> is a response object with the following read-only accessors
+(see the API documentation for the meaning of each.)
+
+    $res->status();     #=> Str
+    $res->broadcast();  #=> Num
+    $res->targeting();  #=> Num
+
+Notice that the "status" does not mean HTTP status. To inspect actual
+HTTP status, invoke C<$res->http_status()>.
+
 =head2 C<< get_profile($user_id) >>
 
 Get user profile information.
@@ -573,6 +620,12 @@ Get user profile information.
 
 See also the LINE Developers API reference of this method:  L<https://developers.line.biz/en/reference/messaging-api/#get-profile>
 
+=head2 C<< get_friend_demographics >>
+
+Retrieves the demographic attributes for a LINE Official Account's friends.
+
+See also the LINE Developers API reference of this method: L<https://developers.line.biz/en/reference/messaging-api/#get-demographic>
+
 =head2 C<< get_group_member_profile($group_id, $user_id) >>
 
 Get group user profile information.
@@ -763,6 +816,32 @@ The argument is a HashRef with one pair of mandatary key-values;
 
 Upon successful revocation, a 200 OK HTTP response is returned. Otherwise, you my examine the "error" attribute and "error_description" attribute for more information about the error.
 
+=head2 C<< get_number_of_followers({ date => "..." }) >>
+
+This method corresponds to the API of: L<Get number of followers|https://developers.line.biz/en/reference/messaging-api/#get-number-of-followers>
+
+The argument is a HashRef with one pair of mandatary key-values;
+
+    { date => "20191231" }
+
+The formate of date is "yyyyMMdd", that is, year in 4 digits, month in
+2 digits, and date-of-month in 2 digits.
+
+Upon successful invocation, a 200 OK HTTP response is
+returned. Otherwise, you my examine the "error" attribute and
+"error_description" attribute for more information about the error.
+
+The return value C<$res> is a response object with the following read-only accessors
+(see the API documentation for the meaning of each.)
+
+    $res->status();          #=> Str, one of: "ready", "unready", "out_of_service"
+    $res->followers();       #=> Num
+    $res->targetedReaches(); #=> Num
+    $res->blocks();          #=> Num
+
+Notice that the "status" does not mean HTTP status. To inspect actual
+HTTP status, invoke C<$res->http_status()>.
+
 =head1 How to build a send message object
 
 See the LINE Developers API reference about L<Message objects|https://developers.line.biz/en/reference/messaging-api/#message-objects>
